/*	scsi.c - choose a scsi driver.		Author: Osamu Ishibashi
 *						Based on wini.c by Kees J. Bot
 *								21 Nov 1997
 * Several different scsi drivers may be compiled
 * into the kernel, but only one may run.  That one is chosen here using
 * the boot variable 'scsi'.
 */

#include "kernel.h"
#include "driver.h"

#if ENABLE_SCSI

/* Map driver name to task function. */
struct scmap {
  char		*name;
  task_t	*task;
} scmap[] = {

#if ENABLE_AHA_SCSI
  { "aha",	aha_scsi_task	},
#endif

#if ENABLE_SPC_SCSI
  { "spc",	spc_scsi_task	},
#endif

};


/*===========================================================================*
 *				scsi_task				     *
 *===========================================================================*/
PUBLIC void scsi_task()
{
  /* Call the default or selected scsi task. */
  char *scsi;
  struct scmap *map;

  scsi = k_getenv("scsi");

  for (map = scmap; map < scmap + sizeof(scmap)/sizeof(scmap[0]); map++) {
	if (scsi == NULL || strcmp(scsi, map->name) == 0) {
		/* Run the selected scsi task. */
		(*map->task)();
	}
  }
  panic("no scsi driver", NO_NUM);
}
#endif /* ENABLE_SCSI */

